pygeodesy.deprecated.classes.XDist

Package pygeodesy :: Package deprecated :: Module classes :: Class XDist |
[frames] | no frames]

# Class XDist

    object --+
             |
          dict --+
                 |
       named.ADict --+
                     |
                    XDist

DEPRECATED on 2024.07.02, use class ADict.

Instance Methods
    new empty dictionary
__init__(self, *args, **kwds) x.__init__(...) initializes x; see help(type(x)) for signature |
Inherited from `named.ADict`: `__getattr__`, `__repr__`, `__setattr__`, `__str__`, `set_`, `toRepr`, `toStr` Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `named.ADict`: `iteration`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, *args, **kwds) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Returns:
    new empty dictionary
Overrides: object.__init__ (inherited documentation)